# Merengue Adwaita plugin
#
# Copyright (C) 2022  Juan Pablo Ugarte
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation;
# version 2.1 of the License.
#
# library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
#
# Authors:
#   Juan Pablo Ugarte <juanpablougarte@gmail.com>
#
# SPDX-License-Identifier: LGPL-2.1-only
#

import gi

gi.require_version("Adw", "1")
from gi.repository import GObject, Adw

Adw.init()

from .mrg_adw_application_window import MrgAdwApplicationWindow
from .mrg_adw_bin import MrgAdwBin
from .mrg_adw_carousel import MrgAdwCarousel
from .mrg_adw_window import MrgAdwWindow
from .mrg_adw_dialog import MrgAdwDialog
from .mrg_adw_view_stack import MrgAdwViewStack
from .mrg_adw_view_stack_page import MrgAdwViewStackPage

